@@ -2,7 +2,7 @@
 #
 #       cons.py
 #
-#       Copyright 2009-2017 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2018 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -21,15 +21,15 @@
 
 import os
 import sys
+import tempfile
 
 
-VERSION = "0.38.4"
+VERSION = "0.38.5"
 APP_NAME = "cherrytree"
 NEWER_VERSION_URL = "http://www.giuspen.com/software/version_cherrytree"
 if sys.platform.startswith("win"):
     IS_WIN_OS = True
     SZA_PATH = '"'+os.path.join(SHARE_PATH, "7za.exe")+'"'
-    TMP_FOLDER = os.path.join(os.environ['TEMP'], 'ct_tmp/')
     GLADE_PATH = os.path.join(SHARE_PATH, 'glade/')
     SPECS_PATH = os.path.join(SHARE_PATH, 'language-specs/')
     LOCALE_PATH = os.path.join(SHARE_PATH, 'locale/')
@@ -40,7 +40,6 @@ if sys.platform.startswith("win"):
 else:
     IS_WIN_OS = False
     SZA_PATH = "7za"
-    TMP_FOLDER = os.environ['TEMP'] if 'TEMP' in os.environ else '/tmp/ct_tmp/'
     MODULES_PATH = os.path.dirname(os.path.realpath(__file__))
     CONFIG_DIR = os.path.join(os.path.expanduser('~'), '.config', 'cherrytree')
     if SHARE_PATH == os.path.dirname(MODULES_PATH):
@@ -56,6 +55,7 @@ else:
 CONFIG_PATH = os.path.join(CONFIG_DIR, 'config.cfg')
 LANG_PATH = os.path.join(CONFIG_DIR, 'lang')
 IMG_PATH = os.path.join(CONFIG_DIR, 'img_tmp.png')
+TMP_FOLDER = tempfile.mkdtemp()
 
 try:
     import appindicator
@@ -245,7 +245,7 @@ STOCKS_N_FILES = [
 'node_bullet', 'node_no_icon', CHERRY_BLACK, CHERRY_BLUE,
 CHERRY_CYAN, CHERRY_GREEN, CHERRY_GRAY, CHERRY_ORANGE,
 CHERRY_ORANGE_DARK, CHERRY_PURPLE, CHERRY_RED, CHERRY_SHERBERT,
-CHERRY_YELLOW, 'image_insert', 'image_edit', 'image_save',
+CHERRY_YELLOW, 'image_insert', 'screenshot_insert', 'image_edit', 'image_save',
 'table_insert', 'table_edit', 'table_save', 'codebox_insert',
 'codebox_edit', 'anchor_insert', 'anchor_edit', 'anchor',
 'insert', 'link_handle', 'link_website', 'cherry_edit',
