@@ -2,7 +2,7 @@
 #
 #       main.py
 #
-#       Copyright 2009-2017 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2018 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@ import gobject
 
 import sys
 import os
+import shutil
 import subprocess
 import gettext
 import __builtin__
@@ -99,7 +100,9 @@ class CherryTreeHandler():
             print "win destroy: runn_win not found"
             i = -1
         self.running_windows.pop(i)
-        if not self.running_windows: gtk.main_quit()
+        if not self.running_windows:
+            gtk.main_quit()
+            shutil.rmtree(cons.TMP_FOLDER)
 
     def server_periodic_check(self):
         """Check Whether the server posted messages"""
